aboutsummaryrefslogtreecommitdiffstats
path: root/test/MC/ELF/tls.s
diff options
context:
space:
mode:
Diffstat (limited to 'test/MC/ELF/tls.s')
-rw-r--r--test/MC/ELF/tls.s16
1 files changed, 14 insertions, 2 deletions
diff --git a/test/MC/ELF/tls.s b/test/MC/ELF/tls.s
index 395c270..19e0c76 100644
--- a/test/MC/ELF/tls.s
+++ b/test/MC/ELF/tls.s
@@ -1,15 +1,27 @@
// RUN: llvm-mc -filetype=obj -triple x86_64-pc-linux-gnu %s -o - | elf-dump | FileCheck %s
-// Test that foobar is of type STT_TLS.
+// Test that foo and foobar is of type STT_TLS.
+
+ leaq foo@TLSGD(%rip), %rdi
.section .zed,"awT",@progbits
foobar:
.long 43
-// CHECK: (('st_name', 0x00000001) # 'foobar'
+// CHECK: (('st_name', 0x00000005) # 'foobar'
// CHECK-NEXT: ('st_bind', 0x00000000)
// CHECK-NEXT: ('st_type', 0x00000006)
// CHECK-NEXT: ('st_other', 0x00000000)
// CHECK-NEXT: ('st_shndx', 0x00000004)
// CHECK-NEXT: ('st_value', 0x00000000)
// CHECK-NEXT: ('st_size', 0x00000000)
+// CHECK-NEXT: ),
+
+// CHECK: (('st_name', 0x00000001) # 'foo'
+// CHECK-NEXT: ('st_bind', 0x00000001)
+// CHECK-NEXT: ('st_type', 0x00000006)
+// CHECK-NEXT: ('st_other', 0x00000000)
+// CHECK-NEXT: ('st_shndx', 0x00000000)
+// CHECK-NEXT: ('st_value', 0x00000000)
+// CHECK-NEXT: ('st_size', 0x00000000)
+// CHECK-NEXT: ),